@@ -28,12 +28,11 @@ from oslo_utils import fnmatch
 from oslo_utils import timeutils
 import six
 from stevedore import extension
-import tenacity
 
 from ceilometer import declarative
 from ceilometer import dispatcher
-from ceilometer.i18n import _LE, _LW
 from ceilometer import gnocchi_client
+from ceilometer.i18n import _
 from ceilometer import keystone_client
 
 NAME_ENCODED = __name__.encode('utf-8')
@@ -92,10 +91,10 @@ class ResourcesDefinition(object):
         for field, field_type in expected.items():
             if field not in definition:
                 raise declarative.ResourceDefinitionException(
-                    _LE("Required field %s not specified") % field, definition)
+                    _("Required field %s not specified") % field, definition)
             if not isinstance(definition[field], field_type):
                 raise declarative.ResourceDefinitionException(
-                    _LE("Required field %(field)s should be a %(type)s") %
+                    _("Required field %(field)s should be a %(type)s") %
                     {'field': field, 'type': field_type}, definition)
 
     @staticmethod
@@ -171,7 +170,7 @@ class LockedDefaultDict(defaultdict):
 
 class GnocchiDispatcher(dispatcher.MeterDispatcherBase,
                         dispatcher.EventDispatcherBase):
-    """Dispatcher class for recording metering data into database.
+    """Dispatcher class for recording metering data into the Gnocchi service.
 
     The dispatcher class records each meter into the gnocchi service
     configured in ceilometer configuration file. An example configuration may
@@ -211,29 +210,15 @@ class GnocchiDispatcher(dispatcher.MeterDispatcherBase,
         except ImportError:
             pass
         except oslo_cache.exception.ConfigurationError as exc:
-            LOG.warning(_LW('unable to configure oslo_cache: %s') % exc)
+            LOG.warning('unable to configure oslo_cache: %s', exc)
 
         self._gnocchi_project_id = None
         self._gnocchi_project_id_lock = threading.Lock()
         self._gnocchi_resource_lock = LockedDefaultDict(threading.Lock)
 
         self._gnocchi = gnocchi_client.get_gnocchiclient(conf)
-
-        retries = conf.storage.max_retries
-
-        @tenacity.retry(
-            wait=tenacity.wait_fixed(conf.storage.retry_interval),
-            stop=(tenacity.stop_after_attempt(retries) if retries >= 0
-                  else tenacity.stop_never),
-            reraise=True)
-        def _get_connection():
-            self._gnocchi.capabilities.list()
-
-        try:
-            _get_connection()
-        except Exception:
-            LOG.error(_LE('Failed to connect to Gnocchi.'))
-            raise
+        self._already_logged_event_types = set()
+        self._already_logged_metric_names = set()
 
     @classmethod
     def _load_resources_definitions(cls, conf):
@@ -250,7 +235,7 @@ class GnocchiDispatcher(dispatcher.MeterDispatcherBase,
                     resource,
                     conf.dispatcher_gnocchi.archive_policy, plugin_manager))
             except Exception as exc:
-                LOG.error(_LE("Failed to load resource due to error %s") %
+                LOG.error("Failed to load resource due to error %s" %
                           exc)
         return resource_defs
 
@@ -264,13 +249,14 @@ class GnocchiDispatcher(dispatcher.MeterDispatcherBase,
                     project = self._ks_client.projects.find(
                         name=self.conf.dispatcher_gnocchi.filter_project)
                 except ka_exceptions.NotFound:
-                    LOG.warning(_LW('gnocchi project not found in keystone,'
-                                    ' ignoring the filter_service_activity '
-                                    'option'))
+                    LOG.warning('gnocchi project not found in keystone,'
+                                ' ignoring the filter_service_activity '
+                                'option')
                     self.filter_service_activity = False
                     return None
                 except Exception:
-                    LOG.exception('fail to retrieve user of Gnocchi service')
+                    LOG.exception('fail to retrieve user of Gnocchi '
+                                  'service')
                     raise
                 self._gnocchi_project_id = project.id
                 LOG.debug("gnocchi project found: %s", self.gnocchi_project_id)
@@ -308,14 +294,7 @@ class GnocchiDispatcher(dispatcher.MeterDispatcherBase,
         # NOTE(sileht): skip sample generated by gnocchi itself
         data = [s for s in data if not self._is_gnocchi_activity(s)]
 
-        # FIXME(sileht): This method bulk the processing of samples
-        # grouped by resource_id and metric_name but this is not
-        # efficient yet because the data received here doesn't often
-        # contains a lot of different kind of samples
-        # So perhaps the next step will be to pool the received data from
-        # message bus.
         data.sort(key=lambda s: (s['resource_id'], s['counter_name']))
-
         resource_grouped_samples = itertools.groupby(
             data, key=operator.itemgetter('resource_id'))
 
@@ -338,8 +317,10 @@ class GnocchiDispatcher(dispatcher.MeterDispatcherBase,
                 samples = list(samples)
                 rd = self._get_resource_definition_from_metric(metric_name)
                 if rd is None:
-                    LOG.warning(_LW("metric %s is not handled by Gnocchi") %
-                                metric_name)
+                    if metric_name not in self._already_logged_metric_names:
+                        LOG.warning("metric %s is not handled by Gnocchi" %
+                                    metric_name)
+                        self._already_logged_metric_names.add(metric_name)
                     continue
                 if rd.cfg.get("ignore"):
                     continue
@@ -419,7 +400,7 @@ class GnocchiDispatcher(dispatcher.MeterDispatcherBase,
                     # NOTE(sileht): resource created in the meantime
                     pass
                 except gnocchi_exc.ClientException as e:
-                    LOG.error(_LE('Error creating resource %(id)s: %(err)s'),
+                    LOG.error('Error creating resource %(id)s: %(err)s',
                               {'id': resource['id'], 'err': six.text_type(e)})
                     # We cannot post measures for this resource
                     # and we can't patch it later
@@ -487,8 +468,10 @@ class GnocchiDispatcher(dispatcher.MeterDispatcherBase,
         for event in events:
             rd = self._get_resource_definition_from_event(event['event_type'])
             if not rd:
-                LOG.debug("No gnocchi definition for event type: %s",
-                          event['event_type'])
+                if event['event_type'] not in self._already_logged_event_types:
+                    LOG.debug("No gnocchi definition for event type: %s",
+                              event['event_type'])
+                    self._already_logged_event_types.add(event['event_type'])
                 continue
 
             rd, operation = rd
@@ -517,8 +500,8 @@ class GnocchiDispatcher(dispatcher.MeterDispatcherBase,
             return self._gnocchi.resource.search(
                 resource_type, jsonutils.loads(query))
         except Exception:
-            LOG.error(_LE("Fail to search resource type %{resource_type}s "
-                          "with '%{query}s'"),
+            LOG.error("Fail to search resource type %{resource_type}s "
+                      "with '%{query}s'",
                       {'resource_type': resource_type, 'query': query},
                       exc_info=True)
         return []
@@ -531,6 +514,6 @@ class GnocchiDispatcher(dispatcher.MeterDispatcherBase,
             LOG.debug("Delete event received on unexisting resource (%s), "
                       "ignore it.", resource['id'])
         except Exception:
-            LOG.error(_LE("Fail to update the resource %s"), resource,
+            LOG.error("Fail to update the resource %s", resource,
                       exc_info=True)
         LOG.debug('Resource %s ended at %s' % (resource["id"], ended_at))
