@@ -17,7 +17,6 @@ from oslo_log import log
 from oslo_utils import timeutils
 
 from ceilometer.agent import plugin_base
-from ceilometer.i18n import _LE
 from ceilometer import nova_client
 
 
@@ -129,7 +128,7 @@ class NodesDiscoveryTripleO(plugin_base.DiscoveryBase):
 
                 resources.append(resource)
             except KeyError:
-                LOG.error(_LE("Couldn't obtain IP address of "
-                              "instance %s") % instance.id)
+                LOG.error("Couldn't obtain IP address of "
+                          "instance %s" % instance.id)
 
         return resources
