@@ -12,9 +12,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
 from oslo_log import log
-from oslo_utils import timeutils
 
 from ceilometer.agent import plugin_base
 from ceilometer.i18n import _
@@ -23,11 +21,6 @@ from ceilometer.ipmi.platform import exception as ipmiexcept
 from ceilometer.ipmi.platform import ipmi_sensor
 from ceilometer import sample
 
-CONF = cfg.CONF
-CONF.import_opt('host', 'ceilometer.service')
-CONF.import_opt('polling_retry', 'ceilometer.ipmi.pollsters',
-                group='ipmi')
-
 LOG = log.getLogger(__name__)
 
 
@@ -69,8 +62,7 @@ class SensorPollster(plugin_base.PollsterBase):
                 'Polling %(mtr)s sensor failed for %(cnt)s times!')
                 % ({'mtr': self.METRIC,
                     'cnt': self.polling_failures}))
-            if (CONF.ipmi.polling_retry >= 0 and
-                    self.polling_failures > CONF.ipmi.polling_retry):
+            if 0 <= self.conf.ipmi.polling_retry < self.polling_failures:
                 LOG.warning(_('Pollster for %s is disabled!') % self.METRIC)
                 raise plugin_base.PollsterPermanentError(resources)
             else:
@@ -97,12 +89,12 @@ class SensorPollster(plugin_base.PollsterBase):
                 continue
 
             resource_id = '%(host)s-%(sensor-id)s' % {
-                'host': CONF.host,
+                'host': self.conf.host,
                 'sensor-id': parser.transform_id(sensor_id)
             }
 
             metadata = {
-                'node': CONF.host
+                'node': self.conf.host
             }
 
             yield sample.Sample(
@@ -113,7 +105,6 @@ class SensorPollster(plugin_base.PollsterBase):
                 user_id=None,
                 project_id=None,
                 resource_id=resource_id,
-                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=metadata)
 
 
