@@ -19,6 +19,7 @@ import hashlib
 from itertools import chain
 from operator import methodcaller
 import os
+import pkg_resources
 
 from oslo_config import cfg
 from oslo_log import log
@@ -30,7 +31,6 @@ from stevedore import extension
 import yaml
 
 from ceilometer.event.storage import models
-from ceilometer.i18n import _LI, _LW, _LE
 from ceilometer import publisher
 from ceilometer.publisher import utils as publisher_utils
 from ceilometer import sample as sample_util
@@ -44,19 +44,6 @@ OPTS = [
                default="event_pipeline.yaml",
                help="Configuration file for event pipeline definition."
                ),
-    cfg.BoolOpt('refresh_pipeline_cfg',
-                default=False,
-                help="Refresh Pipeline configuration on-the-fly."
-                ),
-    cfg.BoolOpt('refresh_event_pipeline_cfg',
-                default=False,
-                help="Refresh Event Pipeline configuration on-the-fly."
-                ),
-    cfg.IntOpt('pipeline_polling_interval',
-               default=20,
-               help="Polling interval for pipeline file configuration"
-                    " in seconds."
-               ),
 ]
 
 
@@ -431,7 +418,7 @@ class Sink(object):
             try:
                 self.publishers.append(publisher_manager.get(p))
             except Exception:
-                LOG.error(_LE("Unable to load publisher %s"), p,
+                LOG.error("Unable to load publisher %s", p,
                           exc_info=True)
 
         self.multi_publish = True if len(self.publishers) > 1 else False
@@ -451,11 +438,11 @@ class Sink(object):
                     "No transformer named %s loaded" % transformer['name'],
                     cfg)
             transformers.append(ext.plugin(**parameter))
-            LOG.info(_LI(
+            LOG.info(
                 "Pipeline %(pipeline)s: Setup transformer instance %(name)s "
-                "with parameter %(param)s") % ({'pipeline': self,
-                                                'name': transformer['name'],
-                                                'param': parameter}))
+                "with parameter %(param)s" % ({'pipeline': self,
+                                               'name': transformer['name'],
+                                               'param': parameter}))
 
         return transformers
 
@@ -470,8 +457,8 @@ class EventSink(Sink):
                 try:
                     p.publish_events(events)
                 except Exception:
-                    LOG.error(_LE("Pipeline %(pipeline)s: %(status)s "
-                                  "after error from publisher %(pub)s") %
+                    LOG.error("Pipeline %(pipeline)s: %(status)s "
+                              "after error from publisher %(pub)s" %
                               {'pipeline': self,
                                'status': 'Continue' if
                                self.multi_publish else 'Exit', 'pub': p},
@@ -500,11 +487,11 @@ class SampleSink(Sink):
                     return
             return sample
         except Exception:
-            LOG.error(_LE("Pipeline %(pipeline)s: Exit after error "
-                          "from transformer %(trans)s "
-                          "for %(smp)s") % {'pipeline': self,
-                                            'trans': transformer,
-                                            'smp': sample},
+            LOG.error("Pipeline %(pipeline)s: Exit after error "
+                      "from transformer %(trans)s "
+                      "for %(smp)s" % {'pipeline': self,
+                                       'trans': transformer,
+                                       'smp': sample},
                       exc_info=True)
 
     def _publish_samples(self, start, samples):
@@ -536,8 +523,8 @@ class SampleSink(Sink):
                 try:
                     p.publish_samples(transformed_samples)
                 except Exception:
-                    LOG.error(_LE("Pipeline %(pipeline)s: Continue after "
-                                  "error from publisher %(pub)s")
+                    LOG.error("Pipeline %(pipeline)s: Continue after "
+                              "error from publisher %(pub)s"
                               % {'pipeline': self, 'pub': p},
                               exc_info=True)
 
@@ -552,8 +539,8 @@ class SampleSink(Sink):
                 self._publish_samples(i + 1,
                                       list(transformer.flush()))
             except Exception:
-                LOG.error(_LE("Pipeline %(pipeline)s: Error "
-                              "flushing transformer %(trans)s")
+                LOG.error("Pipeline %(pipeline)s: Error "
+                          "flushing transformer %(trans)s"
                           % {'pipeline': self, 'trans': transformer},
                           exc_info=True)
 
@@ -612,10 +599,10 @@ class SamplePipeline(Pipeline):
     def _validate_volume(self, s):
         volume = s.volume
         if volume is None:
-            LOG.warning(_LW(
+            LOG.warning(
                 'metering data %(counter_name)s for %(resource_id)s '
                 '@ %(timestamp)s has no volume (volume: None), the sample will'
-                ' be dropped')
+                ' be dropped'
                 % {'counter_name': s.name,
                    'resource_id': s.resource_id,
                    'timestamp': s.timestamp if s.timestamp else 'NO TIMESTAMP'}
@@ -625,10 +612,10 @@ class SamplePipeline(Pipeline):
             try:
                 volume = float(volume)
             except ValueError:
-                LOG.warning(_LW(
+                LOG.warning(
                     'metering data %(counter_name)s for %(resource_id)s '
                     '@ %(timestamp)s has volume which is not a number '
-                    '(volume: %(counter_volume)s), the sample will be dropped')
+                    '(volume: %(counter_volume)s), the sample will be dropped'
                     % {'counter_name': s.name,
                        'resource_id': s.resource_id,
                        'timestamp': (
@@ -664,12 +651,17 @@ class ConfigManagerBase(object):
         self.conf = conf
         self.cfg_loc = None
 
-    def load_config(self, cfg_file):
+    def load_config(self, cfg_file, fallback_cfg_prefix='pipeline/data/'):
         """Load a configuration file and set its refresh values."""
         if os.path.exists(cfg_file):
             self.cfg_loc = cfg_file
         else:
             self.cfg_loc = self.conf.find_file(cfg_file)
+        if not self.cfg_loc and fallback_cfg_prefix is not None:
+            LOG.debug("No pipeline definitions configuration file found! "
+                      "Using default config.")
+            self.cfg_loc = pkg_resources.resource_filename(
+                __name__, fallback_cfg_prefix + cfg_file)
         with open(self.cfg_loc) as fap:
             data = fap.read()
         conf = yaml.safe_load(data)
@@ -699,11 +691,11 @@ class ConfigManagerBase(object):
         """Returns hash of changed cfg else False."""
         mtime = self.get_cfg_mtime()
         if mtime > self.cfg_mtime:
-            LOG.info(_LI('Configuration file has been updated.'))
+            LOG.info('Configuration file has been updated.')
             self.cfg_mtime = mtime
             _hash = self.get_cfg_hash()
             if _hash != self.cfg_hash:
-                LOG.info(_LI("Detected change in configuration."))
+                LOG.info("Detected change in configuration.")
                 return _hash
         return False
 
@@ -789,7 +781,7 @@ class PipelineManager(ConfigManagerBase):
         if not ('sources' in cfg and 'sinks' in cfg):
             raise PipelineException("Both sources & sinks are required",
                                     cfg)
-        LOG.info(_LI('detected decoupled pipeline config format'))
+        LOG.info('detected decoupled pipeline config format')
         publisher_manager = PublisherManager(self.conf, p_type['name'])
 
         unique_names = set()
@@ -882,8 +874,9 @@ class PollingManager(ConfigManagerBase):
         try:
             cfg = self.load_config(cfg_file)
         except (TypeError, IOError):
-            LOG.warning(_LW('Unable to locate polling configuration, falling '
-                            'back to pipeline configuration.'))
+            LOG.warning('Using the pipeline configuration for polling '
+                        'is deprecated. %s should '
+                        'be used instead.', cfg_file)
             cfg = self.load_config(conf.pipeline_cfg_file)
         self.sources = []
         if 'sources' not in cfg:
