@@ -22,7 +22,7 @@ from ceilometer.storage import impl_log
 class ConnectionTest(base.BaseTestCase):
     @staticmethod
     def test_get_connection():
-        conn = impl_log.Connection(None)
+        conn = impl_log.Connection(None, None)
         conn.record_metering_data({'counter_name': 'test',
                                    'resource_id': __name__,
                                    'counter_volume': 1,
