@@ -13,10 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import fixture as fixture_config
 import oslo_messaging
 
 from ceilometer.api import hooks
+from ceilometer import service
 from ceilometer.tests import base
 
 
@@ -24,11 +24,9 @@ class TestTestNotifierHook(base.BaseTestCase):
 
     def setUp(self):
         super(TestTestNotifierHook, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF = service.prepare_service([], [])
 
     def test_init_notifier_with_drivers(self):
-        self.CONF.set_override('telemetry_driver', 'messagingv2',
-                               group='publisher_notifier')
         hook = hooks.NotifierHook(self.CONF)
         notifier = hook.notifier
         self.assertIsInstance(notifier, oslo_messaging.Notifier)
