@@ -15,18 +15,18 @@
 import datetime
 
 import mock
-from oslo_config import fixture as fixture_config
 from oslotest import base
 
 from ceilometer.dispatcher import database
 from ceilometer.publisher import utils
+from ceilometer import service
 
 
 class TestDispatcherDB(base.BaseTestCase):
 
     def setUp(self):
         super(TestDispatcherDB, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF = service.prepare_service([], [])
         self.CONF.set_override('connection', 'sqlite://', group='database')
         self.meter_dispatcher = database.MeterDatabaseDispatcher(self.CONF)
 
