@@ -13,14 +13,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import fixture as fixture_config
 from oslotest import base
 
+from ceilometer import service
+
 
 class _PollsterTestBase(base.BaseTestCase):
     def setUp(self):
         super(_PollsterTestBase, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF = service.prepare_service([], [])
 
     def _test_pollster(self, pollster_class, meter_name,
                        meter_type, meter_unit):
