@@ -18,13 +18,10 @@
 
 """Utilities and helper functions."""
 
-import bisect
 import calendar
 import copy
 import datetime
 import decimal
-import hashlib
-import struct
 import threading
 import time
 
@@ -141,7 +138,10 @@ def decimal_to_dt(dec):
 
 
 def sanitize_timestamp(timestamp):
-    """Return a naive utc datetime object."""
+    """Return a naive utc datetime object.
+
+    :returns: a timezone unaware timestamp
+    """
     if not timestamp:
         return timestamp
     if not isinstance(timestamp, datetime.datetime):
@@ -219,37 +219,6 @@ def hash_of_set(s):
     return str(hash(frozenset(s)))
 
 
-class HashRing(object):
-
-    def __init__(self, nodes, replicas=100):
-        self._ring = dict()
-        self._sorted_keys = []
-
-        for node in nodes:
-            for r in six.moves.range(replicas):
-                hashed_key = self._hash('%s-%s' % (node, r))
-                self._ring[hashed_key] = node
-                self._sorted_keys.append(hashed_key)
-        self._sorted_keys.sort()
-
-    @staticmethod
-    def _hash(key):
-        return struct.unpack_from('>I',
-                                  hashlib.md5(decode_unicode(six
-                                              .text_type(key))).digest())[0]
-
-    def _get_position_on_ring(self, key):
-        hashed_key = self._hash(key)
-        position = bisect.bisect(self._sorted_keys, hashed_key)
-        return position if position < len(self._sorted_keys) else 0
-
-    def get_node(self, key):
-        if not self._ring:
-            return None
-        pos = self._get_position_on_ring(key)
-        return self._ring[self._sorted_keys[pos]]
-
-
 def kill_listeners(listeners):
     # NOTE(gordc): correct usage of oslo.messaging listener is to stop(),
     # which stops new messages, and wait(), which processes remaining
